# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# TODO: BR: perl(Test::Pod::LinkCheck) when available
# TODO: BR: perl(Test::Pod::No404s) when available

Name:		perl-Devel-StackTrace
Summary:	Perl module implementing stack trace and stack trace frame objects
Epoch:		1
Version:	2.04
Release:	1.%{__distinit}%{__distvers}
License:	Artistic 2.0
URL:		https://metacpan.org/release/Devel-StackTrace
Source:		https://cpan.metacpan.org/modules/by-module/Devel/Devel-StackTrace-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(bytes)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
# Exception::Class → Devel::StackTrace
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exception::Class)
%endif
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
The Devel::StackTrace module contains two classes, Devel::StackTrace
and Devel::StackTraceFrame. The goal of this object is to encapsulate
the information that can found through using the caller() function, as
well as providing a simple interface to this data.

The Devel::StackTrace object contains a set of Devel::StackTraceFrame
objects, one for each level of the stack. The frames contain all the
data available from caller().

%prep
%setup -q -n Devel-StackTrace-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%{perl_vendorlib}/Devel/
%{_mandir}/man3/Devel::StackTrace.3*
%{_mandir}/man3/Devel::StackTrace::Frame.3*

%changelog
* Sat May 25 2019 Paul Howarth <paul@city-fan.org> - 1:2.04-1
- Update to 2.04
  - Add a partial workaround for "Bizarre copy" errors (GH#11) that come when
    attempting to look at arguments in the call stack; this is only a partial
    fix (GH#21) as there are cases that can lead to a SEGV - ultimately, this
    needs to be fixed in the Perl core (Perl RT#131046)
- Package new upstream CODE_OF_CONDUCT.md file
- Switch upstream from search.cpan.org to metacpan.org

* Mon Nov 20 2017 Paul Howarth <paul@city-fan.org> - 1:2.03-1
- Update to 2.03
  - If all frames in the trace were skipped (via skip_frames, frame_filter,
    ignore_*, etc.), then the stringified stack trace would be an empty string;
    this has been changed to always return the message given to the constructor
    or the string "Trace begun" (GH#15)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96

* Fri Dec  9 2016 Paul Howarth <paul@city-fan.org> - 1:2.02-1
- Update to 2.02
  - Switch to GitHub Issues
  - Some small pod fixes
- Author/Release tests moved to xt/, don't bother tring to run them
- Update patch for building with old Test::More versions

* Thu Aug 18 2016 Paul Howarth <paul@city-fan.org> - 1:2.01-2
- BR: perl-generators where possible
- Simplify find command using -delete

* Thu Mar  3 2016 Paul Howarth <paul@city-fan.org> - 1:2.01-1
- Update to 2.01
  - Fixed the frames method when it is called with arguments; previously this
    didn't work if it was called before the method was called as a reader (PR#8)
- Update patch for building with old Test::More versions
- Add patch to support building without Test::Code::TidyAll

* Sun Nov  2 2014 Paul Howarth <paul@city-fan.org> - 1:2.00-1
- Update to 2.00
  BACKWARDS INCOMPATIBILITIES
  - The no_refs constructor parameter is now deprecated, and has been replaced
    by a new unsafe_ref_capture parameter that defaults to false, meaning no
    references are captured by default; capturing references by default caused
    too many issues that couldn't be worked around, including running DESTROY
    blocks multiple times on captured objects in the worst case
  - Removed support for the long-deprecated no_object_refs constructor
    parameter (deprecated in 2002!)
- Update patch for building with old Test::More versions
- Classify buildreqs by usage

* Wed Aug 27 2014 Paul Howarth <paul@city-fan.org> - 1:1.34-2
- BR: perl(Test::More)
- Use %%license where possible

* Fri Jun 27 2014 Paul Howarth <paul@city-fan.org> - 1:1.34-1
- Update to 1.34
  - Added a skip_frames option, which causes the stack trace to skip an
    arbitrary number of frames
    (https://github.com/autarch/Devel-StackTrace/pull/5)
- Update patch for building with old Test::More versions

* Mon May  5 2014 Paul Howarth <paul@city-fan.org> - 1:1.32-1
- Update to 1.32
  - Added a filter_frames_early option to filter frames before arguments are
    stringified (PR #4)
- Update patch for building with old Test::More versions
- Drop support for old distributions prior to FC-5
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch supporting building with ExtUtils::MakeMaker < 6.30

* Fri Jan 17 2014 Paul Howarth <paul@city-fan.org> - 1:1.31-1
- Update to 1.31
  - Documentation updates, including documenting the as_string() method in
    Devel::StackTrace::Frame (CPAN RT#91575)
- Drop spelling patch, no longer needed

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 1:1.30-3
- Perl 5.18 rebuild

* Tue May 21 2013 Paul Howarth <paul@city-fan.org> - 1:1.30-2
- Don't BR: perl(Test::Spelling) when bootstrapping, and don't run the
  release tests either, since they'd fail without it

* Tue Nov 20 2012 Paul Howarth <paul@city-fan.org> - 1:1.30-1
- Update to 1.30
  - There was an eval that did not first localize $@ and $SIG{__DIE__}; this
    broke Plack::Middleware::StackTrace (and possibly other things)
- Update patch for building with old Test::More versions
- Fix bogus date in spec changelog

* Sat Nov 17 2012 Paul Howarth <paul@city-fan.org> - 1:1.29-1
- Update to 1.29
  - Allow arguments to a trace's as_string method, specifically max_arg_length
  - Added a no_args option to the constructor in 1.26 but forgot to mention it
    in Changes (CPAN RT#71482)
  - The Devel::StackTrace->frames() method is now read-write, which allows you
    to do more complex filtering of frames than is easily possible with the
    frame_filter argument to the constructor
- Update patches
- Drop BR: perl(Test::Kwalitee); kwalitee test dropped upstream
- BR: perl(Test::CPAN::Changes)

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1:1.27-8
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  1 2012 Paul Howarth <paul@city-fan.org> - 1:1.27-7
- BR: perl(base), perl(Encode), perl(File::Spec) and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - perl(Exception::Class) available for all supported releases now
  - Never need to BR: aspell-en-gb
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 1:1.27-6
- Don't BR: perl(Exception::Class), perl(Test::EOL) or perl(Test::Kwalitee) if
  we're bootstrapping

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 1:1.27-5
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 1:1.27-4
- Test::Spelling now available for all releases

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 1:1.27-3
- BR: perl(Test::Kwalitee) unconditionally

* Tue Mar 22 2011 Paul Howarth <paul@city-fan.org> - 1:1.27-2
- BR: perl(Test::Kwalitee)
- Nobody else likes macros for commands
- Use %%{_fixperms} instead of our own chmod incantation

* Sun Jan 16 2011 Paul Howarth <paul@city-fan.org> - 1:1.27-1
- Update to 1.27 (skip some tests on 5.13.8+ that are no longer relevant
  because of a change in the Perl core - CPAN RT #64828)
- Update patch for old Test::More versions

* Fri Oct 15 2010 Paul Howarth <paul@city-fan.org> - 1:1.26-1
- Update to 1.26 (the as_string method did not localize $@ and $SIG{__DIE__}
  before doing an eval - CPAN RT#61072)
- Update patch for old Test::More versions

* Tue Sep  7 2010 Paul Howarth <paul@city-fan.org> - 1:1.25-1
- Update to 1.25 (Devel::StackTraceFrame was not actually subclassing
  Devel::StackTrace::Frame)
- Update patch for old Test::More versions

* Sun Sep  5 2010 Paul Howarth <paul@city-fan.org> - 1:1.24-1
- Update to 1.24:
  - Version 1.23 was missing a $VERSION assignment
  - Moved the frame object to its own file, and renamed it
    Devel::StackTrace::Frame; the old package name, Devel::StackTraceFrame, is
    now a subclass of the new package, to provide a backwards compatibility shim
- Package manpage for Devel::StackTrace::Frame
- BuildRequires: perl(Exception::Class) for additional test coverage

* Sun Aug 29 2010 Paul Howarth <paul@city-fan.org> - 1:1.23-1
- Update to 1.23:
  - License changed to Artistic 2.0
  - Added message and indent constructor parameters (CPAN RT#59830)
- Use RELEASE_TESTING rather than IS_MAINTAINER for author tests
- BuildRequires: perl(Test::EOL)
- BuildRequires: perl(Test::NoTabs)
- BuildRequires: perl(Test::Spelling), aspell-en if available
- Add patch to cope with absence of Test::Spelling in test suite
- Add patch to cope with Test::More < 0.88

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1:1.22-5
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> - 1:1.22-4
- Fix dist tag for RHEL-6 Beta

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> - 1:1.22-3
- Import from Fedora

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.22-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jul 20 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 1:1.22-1
- Upstream update.

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.20-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 18 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 1:1.20-2
- BR: perl(Test::Kwalitee)

* Sat Dec 13 2008 Ralf Corsépius <corsepiu@fedoraproject.org> - 1:1.20-1
- Upstream update
- Bump epoch

* Fri Aug 08 2008 Ralf Corsépius <rc040203@freenet.de> - 1.1902-1
- Upstream update

* Wed Jun 25 2008 Ralf Corsépius <rc040203@freenet.de> - 1.1901-1
- Upstream update

* Fri May 16 2008 Ralf Corsépius <rc040203@freenet.de> - 1.18-2
- Bump release

* Mon Apr 07 2008 Ralf Corsépius <rc040203@freenet.de> - 1.18-1
- Upstream update

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.16-2
- Rebuild for perl 5.10 (again)

* Sun Feb 03 2008 Ralf Corsépius <rc040203@freenet.de> - 1.16-1
- Upstream update
- Activate IS_MAINTAINER-tests
- BR: perl(Test::Pod::Coverage)

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.15-3
- Rebuild for new perl

* Wed Aug 29 2007 Ralf Corsépius <rc040203@freenet.de> - 1.15-2
- Update License

* Mon Apr 30 2007 Ralf Corsépius <rc040203@freenet.de> - 1.15-1
- Upstream update

* Sat Mar 17 2007 Ralf Corsépius <rc040203@freenet.de> - 1.14-1
- Upstream update

* Tue Sep 05 2006 Ralf Corsépius <rc040203@freenet.de> - 1.13-2
- Mass rebuild

* Tue Apr 04 2006 Ralf Corsépius <rc040203@freenet.de> - 1.13-1
- Upstream update

* Wed Mar 01 2006 Ralf Corsépius <rc040203@freenet.de> - 1.12-2
- Rebuild for perl-5.8.8

* Sun Oct 02 2005 Ralf Corsepius <rc040203@freenet.de> - 1.12-1
- Upstream update
